<?php

namespace Drupal\dr8_zth\Controller;

use Drupal\Component\Utility\Xss;
use Drupal\Core\Controller\ControllerBase;
use Drupal\dr8_zth\BlogInterface;
use Drupal\dr8_zth\BlogTypeInterface;

/**
 * Provides route responses for dr8_zth.module.
 */
class BlogController extends ControllerBase {

  /**
   * Returns a form to add a new term to a vocabulary.
   *
   * @param \Drupal\dr8_zth\BlogTypeInterface $blog_type
   *   The blog type this blog will be added to.
   *
   * @return array
   *   The taxonomy term add form.
   */
  public function addForm(BlogTypeInterface $blog_type) {
    $term = $this->entityTypeManager()
      ->getStorage('blog')
      ->create(['type' => $blog_type->id()]);
    return $this->entityFormBuilder()
      ->getForm($term);
  }

  /**
   * Route title callback.
   *
   * @param \Drupal\dr8_zth\BlogTypeInterface $blog_type
   *   The blog type instance.
   *
   * @return string
   *   The blog type label as a render array.
   */
  public function typeTitle(BlogTypeInterface $blog_type) {
    return ['#markup' => $blog_type->label(), '#allowed_tags' => Xss::getHtmlTagList()];
  }

  /**
   * Route title callback.
   *
   * @param \Drupal\dr8_zth\BlogInterface $blog
   *   The blog instance.
   *
   * @return array
   *   The blog label as a render array.
   */
  public function blogTitle(BlogInterface $blog) {
    $ret = ['#markup' => $blog->label(), '#allowed_tags' => Xss::getHtmlTagList()];
    return $ret;
  }

}
