<?php

namespace Drupal\dr8_zth\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Entity\ContentEntityStorageInterface;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class BlogForm is the default add/edit form for Blog entities.
 */
class BlogForm extends ContentEntityForm {

  /**
   * The blog type storage.
   *
   * @var \Drupal\Core\Entity\ConfigEntityStorageInterface
   */
  protected $storage;

  /**
   * BlogTypeForm constructor.
   *
   * @param \Drupal\Core\Entity\ContentEntityStorageInterface $storage
   *   The blog storage.
   */
  public function __construct(ContentEntityStorageInterface $storage) {
    $this->storage = $storage;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $storage = $container->get('entity_type.manager')->getStorage('blog');
    return new static($storage);
  }

  /**
   * Determines if the blog type already exists.
   *
   * @param string $type
   *   The blog type ID.
   *
   * @return bool
   *   TRUE if the blog type exists, FALSE otherwise.
   */
  public function exists($type) {
    $action = $this->storage->load($type);
    return !empty($action);
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $blog = $this->entity;

    $form['type'] = [
      '#type' => 'value',
      '#value' => $blog->bundle(),
    ];

    $form['blog_id'] = [
      '#type' => 'value',
      '#value' => $blog->id(),
    ];

    $form = parent::form($form, $form_state, $blog);
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $channel = 'dr8_zth';
    $blog = $this->entity;
    $result = $blog->save();

    $editLink = $blog
      ->toLink($this->t('Edit'), 'edit-form')
      ->toString();
    $viewLink = $blog
      ->toLink($blog->label(), 'canonical')
      ->toString();
    $event_args = [
      '%blog' => $viewLink,
      'link' => $editLink,
    ];

    switch ($result) {
      case SAVED_NEW:
        drupal_set_message($this->t('Created new %blog blog.', $event_args));
        $this->logger($channel)
          ->notice('Created new %blog blog.', $event_args);
        break;

      case SAVED_UPDATED:
        drupal_set_message($this->t('Updated %blog blog.', $event_args));
        $this->logger($channel)
          ->notice('Updated %name blog.', $event_args);
        break;
    }

    $form_state->setRedirectUrl($blog->toUrl('canonical'));
    $id = $blog->id();
    $form_state->setValue('blog_id', $id);
    $form_state->set('blog_id', $id);
  }

}
